@@ -1,6 +1,8 @@
 package HTTP::Engine::Middleware::Profile;
 use HTTP::Engine::Middleware;
 
+with 'HTTP::Engine::Middleware::Role::Logger';
+
 use Carp ();
 
 has profiler_class => (
@@ -50,15 +52,14 @@ __END__
 
 =head1 NAME
 
-HTTP::Engine::Middleware::Profile - documentation is TODO
+HTTP::Engine::Middleware::Profile - stopwatch for request processing time
 
 =head1 SYNOPSIS
 
     my $mw = HTTP::Engine::Middleware->new;
     $mw->install( 'HTTP::Engine::Middleware::Profile' => {
         logger => sub {
-            my($level, $msg) = @_;
-            warn $mgs;
+            warn @_;
         },
     });
     HTTP::Engine->new(
@@ -68,4 +69,12 @@ HTTP::Engine::Middleware::Profile - documentation is TODO
         }
     )->run();
 
+=head1 DESCRIPTION
+
+This module profile request processing time.
+
+=head1 AUTHORS
+
+dann
+
 =cut
